//-----------------------------------------------------------------------------
// Copyright  1999 - Philip Howard
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//-----------------------------------------------------------------------------
// package	rmd160
// version	1.2.0
// homepage	http://phil.ipal.org/freeware/rmd160/
//-----------------------------------------------------------------------------
// author	Philip Howard
// email	phil@ipal.org
// homepage	http://phil.ipal.org/
//-----------------------------------------------------------------------------

//-----------------------------------------------------------------------------
// program	rmd160-16
//
// purpose	Test and demonstrate the RMD160 library by calculating
//		the RIPEM160 hash checksum for specified files.
//
// syntax	rmd160-16 [ files ... ]
//-----------------------------------------------------------------------------
#include <unistd.h>
#include <sys/stat.h>

#include <fcntl.h>
#include <stddef.h>
#include <stdlib.h>
#include <stdio.h>
#include <sys/stat.h>
#include <sys/types.h>

#include <rmd160.h>

int
do_file (
	int	fd
,
	char *	name
)
{
    RMD160		rmd160_obj	;
    unsigned char	buffer		[ 4096 ];

    rmd160_obj = rmd160_new();
    if ( ! rmd160_obj ) return 0;
    rmd160_append_fd( rmd160_obj , fd );
    if ( rmd160_sum_base16( rmd160_obj , buffer ) == NULL ) return 1;

    fputs( buffer , stdout );
    if ( name ) {
	putchar( ' ' );
	putchar( ' ' );
	puts( name );
    }
    else {
	putchar( '\n' );
    }

    rmd160_destroy( rmd160_obj );
    return 0;
}


//-----------------------------------------------------------------------------
// main
//-----------------------------------------------------------------------------
int
main (
	int		argc
,
	char * *	argv
,
	char * *	envp
)
{
    if ( argc < 2 ) {
	do_file( 0 , NULL );
    }
    else {
	while ( -- argc && * ++ argv ) {
	    {
		struct stat fs;
		if ( stat( * argv , & fs ) != 0 ) continue;
		if ( ! S_ISREG( fs.st_mode ) ) continue;
	    }
	    {
		int fd;
		fd = open( * argv , 0 );
		if ( fd < 0 ) continue;
		do_file( fd , * argv );
		close( fd );
	    }
	}
    }
    return 0;
}    
